#
# spec file for package audaspace
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# See also http://en.opensuse.org/openSUSE:Shared_library_packaging_policy
# NOTE: sover follows version.
%define sover 1_3
%define soversion 1.3

Name:           audaspace
Version:        1.3.0
Release:        lp150.1.7
Summary:        A High-Level Audio Library
License:        Apache-2.0
Group:          Development/Libraries/C and C++
Url:            https://github.com/audaspace/audaspace/releases/tag/v%{version}
Source0:        audaspace-%{version}.tar.gz
#PATCH-FIX-UPSTREAM audaspace-gcc7.patch davejplater@gmail.com -- add missing "#include <functional>" picked up by gcc7
Patch0:         audaspace-gcc7.patch
#PATCH-FIX-UPSTREAM audaspace-plugin-build-options.patch davejplater@gmail.com -- add options for building plugins.
# See boo#1057965
Patch1:         audaspace-plugin-build-options.patch
BuildRequires:  cmake > 3
BuildRequires:  doxygen
BuildRequires:  fdupes
%if 0%{?suse_version} > 1320 || 0%{is_opensuse} == 1
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
%endif
BuildRequires:  gcc-c++
BuildRequires:  graphviz-gnome
BuildRequires:  jack-audio-connection-kit-devel
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(sndfile)
#BuildRequires:  python-devel
#BuildRequires:  python3-Sphinx
BuildRequires:  python3
BuildRequires:  python3-devel
BuildRequires:  python3-numpy-devel
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(sdl2)
#Requires:

%description
Audaspace (pronounced "outer space") is a high-level audio library written
in C++ with language bindings for Python for example. It started out as the
audio engine of the 3D modelling application Blender and is now released as
a standalone library. This package contains demo binaries.

%package        plugins
Summary:        Plugins for %{name}
Group:          System/Libraries
Requires:       %{name} = %{version}

%description    plugins
Audaspace (pronounced "outer space") is a high-level audio library written
in C++ with language bindings for Python for example. It started out as the
audio engine of the 3D modelling application Blender and is now released as
a standalone library. This package contains audio plugins.

%package -n libaudaspace%{sover}
Summary:        A high-level audio library
Group:          System/Libraries

%description -n libaudaspace%{sover}
Audaspace (pronounced "outer space") is a high-level audio library written
in C++ with language bindings for Python for example. It started out as the
audio engine of the 3D modelling application Blender and is now released as
a standalone library.

%package -n libaudaspace-c%{sover}
Summary:        C bindings for %{name}
Group:          System/Libraries

%description -n libaudaspace-c%{sover}
Audaspace (pronounced "outer space") is a high-level audio library written
in C++ with language bindings for Python for example. It started out as the
audio engine of the 3D modelling application Blender and is now released as
a standalone library.

%package -n libaudaspace-py%{sover}
Summary:        Python Bindings for %{name}
Group:          System/Libraries

%description -n libaudaspace-py%{sover}
Audaspace (pronounced "outer space") is a high-level audio library written
in C++ with language bindings for Python for example. It started out as the
audio engine of the 3D modelling application Blender and is now released as
a standalone library.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       %{name}-plugins = %{version}
Requires:       libaudaspace%{sover} = %{version}
Requires:       libaudaspace-c%{sover} = %{version}
Requires:       libaudaspace-py%{sover} = %{version}
Recommends:     %{name}-doc = %{version}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package        doc
Summary:        Documentation for %{name}
Group:          Documentation/HTML
Recommends:     %{name}-devel = %{version}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation for
developing applications that use %{name}.

%prep
%setup -n audaspace-%{version} -q
%patch0
%patch1

%build
tmpflags="%{optflags}"
%ifarch ppc64le
# avoid contentions between SDL vector and gcc defines
# disable the include of altivec.h in /usr/include/SDL2/SDL_cpuinfo.h
# note that --disable-altivec not supported by gcc 4.8
tmpflags="$tmpflags -U__ALTIVEC__"
%endif
# NOTE: python3 numpy include flag (-isystem points to includes) reported upstream.
%cmake -DWITH_VERSIONED_PLUGINS:BOOL=FALSE \
%if 0%{?suse_version} > 1320 || 0%{is_opensuse} == 1
      -DWITH_FFMPEG:BOOL=TRUE \
%else
      -DWITH_FFMPEG:BOOL=FALSE \
%endif
      -DCMAKE_EXE_LINKER_FLAGS:STRING="$CMAKE_EXE_LINKER_FLAGS -pie" \
      -DDEFAULT_PLUGIN_PATH:PATH=%{_libdir}/%{name}-%{soversion}/plugins \
      -DWITH_PYTHON_MODULE:BOOL=off \
      -DCMAKE_C_FLAGS:STRING="%{optflags} -fPIE -isystem %{python3_sitearch}/numpy/core/include/" \
      -DCMAKE_CXX_FLAGS:STRING="${tmpflags} -fPIE -isystem %{python3_sitearch}/numpy/core/include/" \
      -DDOCUMENTATION_INSTALL_PATH:PATH=%{_docdir}/%{name}
%make_jobs

%install
%cmake_install
mkdir -p %{buildroot}%{_docdir}/%{name}/license
cp -v LICENSE AUTHORS CHANGES README.md %{buildroot}%{_docdir}/%{name}/license/
find %{buildroot} -name '*.la' -delete
%fdupes -s %{buildroot}%{_docdir}/%{name}

%post -n libaudaspace%{sover} -p /sbin/ldconfig

%postun -n libaudaspace%{sover} -p /sbin/ldconfig

%post -n libaudaspace-c%{sover} -p /sbin/ldconfig

%postun -n libaudaspace-c%{sover} -p /sbin/ldconfig

%post -n libaudaspace-py%{sover} -p /sbin/ldconfig

%postun -n libaudaspace-py%{sover} -p /sbin/ldconfig

%files
%defattr (-, root, root)
%{_bindir}/*

%files plugins
%defattr (-, root, root)
%dir %{_libdir}/%{name}-%{soversion}
%dir %{_libdir}/%{name}-%{soversion}/plugins
%{_libdir}/%{name}-%{soversion}/plugins/*.so
#%%{_libdir}/%%{name}-%%{soversion}/plugins/*.so

%files -n libaudaspace%{sover}
%defattr (-, root, root)
%{_libdir}/libaudaspace.so.%{soversion}

%files -n libaudaspace-c%{sover}
%defattr (-, root, root)
%{_libdir}/libaudaspace-c.so.%{soversion}

%files -n libaudaspace-py%{sover}
%defattr (-, root, root)
%{_libdir}/libaudaspace-py.so.%{soversion}

%files doc
%defattr (-, root, root)
%dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/*

%files devel
%defattr (-, root, root)
%{_libdir}/pkgconfig/*
%{_includedir}/*
%{_libdir}/*.so

%changelog
* Mon Oct 23 2017 davejplater@gmail.com
- Added upstream patch audaspace-plugin-build-options.patch as
  final fix for boo#1057965 and audaspace issue#10.
- Build example executables as position independent executables.
* Wed Oct 18 2017 davejplater@gmail.com
- Delete plugin symlinks and remove version suffixes to further fix
  boo#1057965 and audaspace issue#10
* Fri Sep 22 2017 davejplater@gmail.com
- Moved lib*.so plugin symlinks from the devel package to the
  pluginsn package as a temporary work around for boo#1057965
  reported upstream https://github.com/audaspace/audaspace/issues/10
* Tue Mar 28 2017 davejplater@gmail.com
- Fix gcc7 build by requiring graphviz-gnome and creating
  audaspace-gcc7.patch to add missing #include <functional>
* Sat Feb 11 2017 jengelh@inai.de
- Rename %%soname to %%sover to better reflect its use.
  Update descriptions.
* Fri Feb 10 2017 davejplater@gmail.com
- Update to release 1.3.0
- Removed patch audaspace-findffmpeg.patch Fixed upstream
- Upstream changes:
  * Audaspace 1.3.0 is a bug fixing release without changes to the
    API, but two small new features:
    linear interpolation for volume changes in the software mixer
    dynamic Loading for JACK
  * Bug fixes:
    renamed Jack to JACK
    C API was not working
    filter python API parameter check
    finding ffmpeg with pkgconfig
* Sun Jul  3 2016 mpluskal@suse.com
- Fix building with recent cmake (macros), which default to -fPIE
* Mon Jun 27 2016 davejplater@gmail.com
- Fixed build with upstream patch audaspace-findffmpeg.patch
* Tue Apr 19 2016 davejplater@gmail.com
- Update to release 1.2
- Upstream changes :
  New features:
    sound list
    random sounds
    dynamic music playing
    playback manager
    convolution/reverbation
    multi-threading
    binaural audio
    API changes:
    changing default sample rate from 44.1 to 48 kHz
    Bug fixes:
    several standard library fixes.
    Bindings API:
    mixdown C API refactored
    CMake/Building:
    assuring numpy is installed
* Tue Feb 16 2016 davejplater@gmail.com
- Added ffmpeg to build for newer that 13.2
* Thu Oct 22 2015 normand@linux.vnet.ibm.com
- for ppc64le architecture disable __ALTIVEC__ to avoid build error
  to avoid contention between SDL vector and gcc defines
* Sat Oct 17 2015 davejplater@gmail.com
- Update to version 1.1
- Remove audaspace-datetime.patch and audaspace-pkgcnflib.patch
  issues fixed upstream.
- Upstream changes:
  * Bug fixes:
    pkgconfig uses cmake configured library directory
    FFMPEG file writing crashed, also corrected pts for encoding
    silenced Doxygen warnings about undefined defines
  * C++ API:
    ResampleReader uses specs instead of sample rate
  * Bindings API:
    writing sounds to files
    reading sound data, specs and length
    resampling sounds
  * CMake/Building:
    first steps towards building for Mac
    windows builds copy dlls automatically
  * Python module:
    using distutils instead of setuptools
    added numpy as dependency
  * Documentation:
    added windows building and plugin documentation
    disabled html timestamps in doxygen
    updated sphinx template
    build binding documentation without installing the python module
* Fri Aug  7 2015 davejplater@gmail.com
- Created package audaspace which was previously a part of blender
  but is an external standalone library as from blender 2.80.
- Created audaspace-datetime.patch to remove time stamps from the
  documentation.
- Created audaspace-pkgcnflib.patch to give the correct _libdir for
  x86_64 builds, it was hardcoded to /lib.
- Features:
  * input/output devices
  input from microphones, line in, etc.
  output devices including 3D audio support
  * file reading/writing
  * filters like low-/highpass and effects like delay, reverse
  or fading
  * generators for simple waveforms like silence, sine and triangle
  * respecification - is used for changing stream parameters which are
  channel count - channel remapping
  sample format - the library internally uses 32 bit floats
  sample rate - resampling
  * simple (superposition, joining and ping-pong aka forward-reverse)
  and more complex (non-linear audio editing) sequencing of sounds
